# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 2.14.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.curia.api.curia.api.curia.api.swagger_client
from curia.api.curia.api.curia.api.curia.api.swagger_client.api.model_batch_jobs_api import ModelBatchJobsApi  # noqa: E501
from curia.api.curia.api.curia.api.curia.api.swagger_client.rest import ApiException


class TestModelBatchJobsApi(unittest.TestCase):
    """ModelBatchJobsApi unit test stubs"""

    def setUp(self):
        self.api = ModelBatchJobsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_many_base_model_batch_job_controller_model_batch_job(self):
        """Test case for create_many_base_model_batch_job_controller_model_batch_job

        Create many ModelBatchJob  # noqa: E501
        """
        pass

    def test_create_one_base_model_batch_job_controller_model_batch_job(self):
        """Test case for create_one_base_model_batch_job_controller_model_batch_job

        Create one ModelBatchJob  # noqa: E501
        """
        pass

    def test_delete_one_base_model_batch_job_controller_model_batch_job(self):
        """Test case for delete_one_base_model_batch_job_controller_model_batch_job

        Delete one ModelBatchJob  # noqa: E501
        """
        pass

    def test_get_many_base_model_batch_job_controller_model_batch_job(self):
        """Test case for get_many_base_model_batch_job_controller_model_batch_job

        Retrieve many ModelBatchJob  # noqa: E501
        """
        pass

    def test_get_one_base_model_batch_job_controller_model_batch_job(self):
        """Test case for get_one_base_model_batch_job_controller_model_batch_job

        Retrieve one ModelBatchJob  # noqa: E501
        """
        pass

    def test_model_batch_job_controller_start(self):
        """Test case for model_batch_job_controller_start

        Start model batch job  # noqa: E501
        """
        pass

    def test_model_batch_job_controller_status(self):
        """Test case for model_batch_job_controller_status

        Retrieve model batch job status  # noqa: E501
        """
        pass

    def test_model_batch_job_controller_stop(self):
        """Test case for model_batch_job_controller_stop

        Stop model batch job  # noqa: E501
        """
        pass

    def test_replace_one_base_model_batch_job_controller_model_batch_job(self):
        """Test case for replace_one_base_model_batch_job_controller_model_batch_job

        Replace one ModelBatchJob  # noqa: E501
        """
        pass

    def test_update_one_base_model_batch_job_controller_model_batch_job(self):
        """Test case for update_one_base_model_batch_job_controller_model_batch_job

        Update one ModelBatchJob  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 2.14.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.curia.api.curia.api.curia.api.swagger_client
from curia.api.curia.api.curia.api.curia.api.swagger_client.api.user_audit_trail_api import UserAuditTrailApi  # noqa: E501
from curia.api.curia.api.curia.api.curia.api.swagger_client.rest import ApiException


class TestUserAuditTrailApi(unittest.TestCase):
    """UserAuditTrailApi unit test stubs"""

    def setUp(self):
        self.api = UserAuditTrailApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_many_base_user_audit_trail_controller_user_audit_trail(self):
        """Test case for get_many_base_user_audit_trail_controller_user_audit_trail

        Retrieve many UserAuditTrail  # noqa: E501
        """
        pass

    def test_get_one_base_user_audit_trail_controller_user_audit_trail(self):
        """Test case for get_one_base_user_audit_trail_controller_user_audit_trail

        Retrieve one UserAuditTrail  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.10.4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateCohortDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'model_id': 'str',
        'train_cohort_id': 'str',
        'cohort_windows': 'list[CohortWindow]',
        'revised_at': 'datetime'
    }

    attribute_map = {
        'name': 'name',
        'model_id': 'modelId',
        'train_cohort_id': 'trainCohortId',
        'cohort_windows': 'cohortWindows',
        'revised_at': 'revisedAt'
    }

    def __init__(self, name=None, model_id=None, train_cohort_id=None, cohort_windows=None, revised_at=None):  # noqa: E501
        """UpdateCohortDto - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._model_id = None
        self._train_cohort_id = None
        self._cohort_windows = None
        self._revised_at = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if model_id is not None:
            self.model_id = model_id
        if train_cohort_id is not None:
            self.train_cohort_id = train_cohort_id
        if cohort_windows is not None:
            self.cohort_windows = cohort_windows
        if revised_at is not None:
            self.revised_at = revised_at

    @property
    def name(self):
        """Gets the name of this UpdateCohortDto.  # noqa: E501


        :return: The name of this UpdateCohortDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateCohortDto.


        :param name: The name of this UpdateCohortDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def model_id(self):
        """Gets the model_id of this UpdateCohortDto.  # noqa: E501


        :return: The model_id of this UpdateCohortDto.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this UpdateCohortDto.


        :param model_id: The model_id of this UpdateCohortDto.  # noqa: E501
        :type: str
        """

        self._model_id = model_id

    @property
    def train_cohort_id(self):
        """Gets the train_cohort_id of this UpdateCohortDto.  # noqa: E501


        :return: The train_cohort_id of this UpdateCohortDto.  # noqa: E501
        :rtype: str
        """
        return self._train_cohort_id

    @train_cohort_id.setter
    def train_cohort_id(self, train_cohort_id):
        """Sets the train_cohort_id of this UpdateCohortDto.


        :param train_cohort_id: The train_cohort_id of this UpdateCohortDto.  # noqa: E501
        :type: str
        """

        self._train_cohort_id = train_cohort_id

    @property
    def cohort_windows(self):
        """Gets the cohort_windows of this UpdateCohortDto.  # noqa: E501


        :return: The cohort_windows of this UpdateCohortDto.  # noqa: E501
        :rtype: list[CohortWindow]
        """
        return self._cohort_windows

    @cohort_windows.setter
    def cohort_windows(self, cohort_windows):
        """Sets the cohort_windows of this UpdateCohortDto.


        :param cohort_windows: The cohort_windows of this UpdateCohortDto.  # noqa: E501
        :type: list[CohortWindow]
        """

        self._cohort_windows = cohort_windows

    @property
    def revised_at(self):
        """Gets the revised_at of this UpdateCohortDto.  # noqa: E501


        :return: The revised_at of this UpdateCohortDto.  # noqa: E501
        :rtype: datetime
        """
        return self._revised_at

    @revised_at.setter
    def revised_at(self, revised_at):
        """Sets the revised_at of this UpdateCohortDto.


        :param revised_at: The revised_at of this UpdateCohortDto.  # noqa: E501
        :type: datetime
        """

        self._revised_at = revised_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateCohortDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateCohortDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
